* Data generated to follow the logit model.

use did_common_6_binary, clear

xtset id year

tab year
tab d if f06
tab y

* Because the data are generated, we can compute the sample ATTs. These 
* are unbiased for the population ATTs. The pre-treatment effects 
* are generated to be zero (no anticipation). The conditional index parallel
* trend assumption holds as in Wooldridge (2023, Econometrics Journal).

gen df01 = d*f01
gen df02 = d*f02
gen df03 = d*f03
gen df04 = d*f04 
gen df05 = d*f05
gen df06 = d*f06  

sum te if df01
sum te if df02
sum te if df03
sum te if df04
sum te if df05
sum te if df06

* Linear model and adjusting standard errors for sampling error in xbar_1.
* This is the same as the extended TWFE in Wooldridge (2021, WP):
	
reg y c.df04 c.df05 c.df06 ///
	c.df04#c.x_dm c.df05#c.x_dm c.df06#c.x_dm ///
	f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x /// 
	d x c.d#c.x, vce(cluster id)
	
margins, dydx(df04) subpop(if df04 == 1) vce(uncond)
margins, dydx(df05) subpop(if df05 == 1) vce(uncond)
margins, dydx(df06) subpop(if df06 == 1) vce(uncond)

* To get a single effect and the proper standard error, introduce c.w.
* Barely makes a difference to the SE in this case.

qui reg y c.w#c.df04 c.w#c.df05 c.w#c.df06 ///
	c.w#c.df04#c.x_dm c.w#c.df05#c.x_dm c.w#c.df06#c.x_dm ///
	f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x /// 
	d x c.d#c.x, vce(cluster id)
	
* Average the three ATTs:
margins, dydx(w) subpop(if w == 1) vce(uncond)
lincom (c.w#c.df04 + c.w#c.df05 + c.w#c.df06)/3

* Introducing i.w allows one to compute an average effect
* across all time periods.

logit y i.w#c.df04 i.w#c.df05 i.w#c.df06 ///
	i.w#c.df04#c.x_dm i.w#c.df05#c.x_dm i.w#c.df06#c.x_dm ///
	f02 f03 f04 f05 f06 c.f02#c.x_dm c.f03#c.x_dm c.f04#c.x_dm c.f05#c.x_dm c.f06#c.x_dm ///
	d x c.d#c.x_dm, noomitted vce(cluster id)
	
* Obtain the ATTs with proper standard errors:	
margins, dydx(w) subpop(if df04 == 1) noestimcheck vce(uncond)
margins, dydx(w) subpop(if df05 == 1) noestimcheck vce(uncond)
margins, dydx(w) subpop(if df06 == 1) noestimcheck vce(uncond)

* Single effect:
margins, dydx(w) subpop(if w == 1) noestimcheck vce(uncond)

/*

* Another way to get the separate ATTs:
	
logit y i.df04 i.df05 i.df06 ///
	i.df04#c.x_dm i.df05#c.x_dm i.df06#c.x_dm ///
	f02 f03 f04 f05 f06 c.f02#c.x_dm c.f03#c.x_dm c.f04#c.x c.f05#c.x_dm c.f06#c.x_dm ///
	d x c.d#c.x_dm, noomitted vce(cluster id)
	
margins, dydx(df04) subpop(if df04 == 1) noestimcheck vce(uncond)
margins, dydx(df05) subpop(if df05 == 1) noestimcheck vce(uncond)
margins, dydx(df06) subpop(if df06 == 1) noestimcheck vce(uncond)

*/


* Logit estimates are much closer to sample ATTs. More precise, too.
	
* Imputation gives same estimates (but without standard errors).
* In the first step, only untreated observations are used:

logit y f02 f03 f04 f05 f06 c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d x c.d#c.x if ~w, noomitted vce(cluster id)

predict double y0hat
gen tehat = y - y0hat
sum tehat if d & f04
sum tehat if d & f05
sum tehat if d & f06

* Now the "event study" estimation and test. Intially, do not interact
* the pre-treatment dummies with the control x. To obtain standard errors,
* it is useful to introduce the non-treated indicator, nw = 1 - w.

gen nw = 1 - w
logit y i.nw#c.df01 i.nw#c.df02 i.w#c.df04 i.w#c.df05 i.w#c.df06 ///
	i.w#c.df04#c.x_dm i.w#c.df05#c.x_dm i.w#c.df06#c.x_dm ///
	f02 f03 f04 f05 f06 c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d x c.d#c.x , vce(cluster id)
test 1.nw#c.df01 1.nw#c.df02

* Confirm get same estimates as using only control observations:
logit y f02 f03 f04 f05 f06 f02#c.x f03#c.x f04#c.x f05#c.x f06#c.x ///
	d x d#c.x_dm df01 df02 if nw, noomitted vce(cluster id)
test df01 df02

* Now the full ES with all interactions. This is the analog of the very 
* long linear ES regression:

logit y i.nw#c.df01 i.nw#c.df02 i.w#c.df04 i.w#c.df05 i.w#c.df06 ///
	i.nw#c.df01#c.x_dm i.nw#c.df02#c.x_dm ///
	i.w#c.df04#c.x_dm i.w#c.df05#c.x_dm i.w#c.df06#c.x_dm ///
	f02 f03 f04 f05 f06 c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d x c.d#c.x , vce(cluster id)
estimates store logit_did
* test 1.nw#c.df01 1.nw#c.df02

margins, dydx(nw) subpop(if df01 == 1) noestimcheck vce(uncond) post
estimates store att_m3
estimates restore logit_did
margins, dydx(nw) subpop(if df02 == 1) noestimcheck vce(uncond) post
estimates store att_m2
estimates restore logit_did
gen zero = 0
reg zero
estimates store att_m1
estimates restore logit_did
margins, dydx(w) subpop(if df04 == 1) noestimcheck vce(uncond) post
estimates store att_0
estimates restore logit_did
margins, dydx(w) subpop(if df05 == 1) noestimcheck vce(uncond) post
estimates store att_1
estimates restore logit_did
margins, dydx(w) subpop(if df06 == 1) noestimcheck vce(uncond) post
estimates store att_2
estimates restore logit_did

coefplot (att_m3, rename(1.nw="-3") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5)) ) ///
         (att_m2, rename(1.nw="-2") mcolor(black)  ciopts(lcolor(blue) recast(rcap) lwidth(0.5) )) ///
         (att_m1, rename(_cons="-1") mcolor(black)) ///
         (att_0, rename(1.w="0") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
         (att_1, rename(1.w="1") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
         (att_2, rename(1.w="2") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))), yline(0) vertical ///
         title("Effects by Exposure Length") ///
         xtitle("Exposure Length") ytitle("Treatment Effects") nokey
		 
graph save did_common_6_logit_es, replace


* SATT averaged across all treated periods:
sum te if w

* Estimated single averaged estimate with proper SE:
margins, dydx(w) subpop(if w == 1) noestimcheck vce(uncond)

* Linear event study equation. The estimates are quite a bit smaller than 
* the logit estimates and SATTs:

reg y c.nw#c.df01 c.nw#c.df02 c.w#c.df04 c.w#c.df05 c.w#c.df06 ///
	c.nw#c.df01#c.x_dm c.nw#c.df02#c.x_dm ///
	c.w#c.df04#c.x_dm c.w#c.df05#c.x_dm c.w#c.df06#c.x_dm ///
	f02 f03 f04 f05 f06 c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d x c.d#c.x , vce(cluster id)
estimates store reg_did
test c.nw#c.df01 c.nw#c.df02

margins, dydx(nw) subpop(if df01 == 1) noestimcheck vce(uncond) post
estimates store att_m3
estimates restore reg_did
margins, dydx(nw) subpop(if df02 == 1) noestimcheck vce(uncond) post
estimates store att_m2
estimates restore reg_did
reg zero
estimates store att_m1
estimates restore reg_did
margins, dydx(w) subpop(if df04 == 1) noestimcheck vce(uncond) post
estimates store att_0
estimates restore reg_did
margins, dydx(w) subpop(if df05 == 1) noestimcheck vce(uncond) post
estimates store att_1
estimates restore reg_did
margins, dydx(w) subpop(if df06 == 1) noestimcheck vce(uncond) post
estimates store att_2
estimates restore reg_did

coefplot (att_m3, rename(nw="-3") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5)) ) ///
         (att_m2, rename(nw="-2") mcolor(black)  ciopts(lcolor(blue) recast(rcap) lwidth(0.5) )) ///
         (att_m1, rename(_cons="-1") mcolor(black)) ///
         (att_0, rename(w="0") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
         (att_1, rename(w="1") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
         (att_2, rename(w="2") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))), yline(0) vertical ///
         title("Effects by Exposure Length") ///
         xtitle("Exposure Length") ytitle("Weighted Treatment Effects") nokey
		 
graph save did_common_6_linear_es, replace

* Average estimate with proper SE:
margins, dydx(w) subpop(if w == 1) noestimcheck vce(uncond)
* Much smaller than the logit, and much smaller than the SATT. Not close
* to statistically significant.

* Callaway and Sant'Anna (2021, Journal of Econometrics).
* For these data, like the linear regression adjustment estimates, 
* the CS doubly robust estimates are too small compared 
* with the SATTs and standard errors are notably larger than the ES logit.
* Linear RA and the DR estimator both assume parallel trends in the mean
* rather than in the log odds.

gen first_treat = 0
replace first_treat = 2004 if d
csdid y x, ivar(id) time(year) gvar(first_treat) long2
estat event
csdid_plot

* Average estimate:
estat simple
* Similar to linear RA and again not significant.

* Imputation in logit ES regression is the same as the pooled, long logit
* regression:

drop y0hat tehat

logit y c.df01 c.df02 c.df01#c.x_dm c.df02#c.x_dm ///
	f02 f03 f04 f05 f06 c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d x c.d#c.x if ~w

predict y0hat 
gen tehat = y - y0hat
sum tehat if df04
sum tehat if df05
sum tehat if df06

* These are zero by logit MLE FOC:
sum tehat if df01
sum tehat if df02

* Heterogeneous trend and compute ATTs with trend. Stata does not
* give the correct answer unless i.w is included:

gen t = year - 2000

logit y i.w#c.df04 i.w#c.df05 i.w#c.df06 ///
	i.w#c.df04#c.x i.w#c.df05#c.x i.w#c.df06#c.x ///
	f02 f03 f04 f05 f06 c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d x c.d#c.x c.d#c.t, noomitted vce(cluster id)
* Obtain the ATTs with proper standard errors:	
margins, dydx(w) at(d = 1 f02 = 0 f03 = 0 f04 = 1 f05 = 0 f06 = 0 t = 4) ///
	subpop(if d == 1) noestimcheck vce(uncond)
margins, dydx(w) at(d = 1 f02 = 0 f03 = 0 f04 = 0 f05 = 1 f06 = 0 t = 5) ///
	subpop(if d == 1) noestimcheck vce(uncond)
margins, dydx(w) at(d = 1 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1 t = 6) ///
	subpop(if d == 1) noestimcheck vce(uncond)
	
margins, dydx(w) subpop(if df04 == 1) noestimcheck vce(uncond)
margins, dydx(w) subpop(if df05 == 1) noestimcheck vce(uncond)
margins, dydx(w) subpop(if df06 == 1) noestimcheck vce(uncond)

drop y0hat tehat

* Imputation with heterogeneous trend:
	
logit y f02 f03 f04 f05 f06 c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d x c.d#c.x c.d#c.t if ~w, noomitted vce(cluster id)
predict double y0hat
gen tehat = y - y0hat
sum tehat if df04
sum tehat if df05
sum tehat if df06

* Linear with heterogeneous trend:
	
reg y i.df04 i.df05 i.df06 ///
	i.df04#c.x_dm i.df05#c.x_dm i.df06#c.x_dm ///
	f02 f03 f04 f05 f06 c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d x c.d#c.x c.d#c.t, noomitted vce(cluster id)
	
margins, dydx(df04) subpop(if df04 == 1) noestimcheck vce(uncond)
margins, dydx(df05) subpop(if df05 == 1) noestimcheck vce(uncond)
margins, dydx(df06) subpop(if df06 == 1) noestimcheck vce(uncond)

/*

* Test for violation of NA by including lead indicator:
logit y i.df04 i.df05 i.df06 ///
	i.df04#c.x_dm i.df05#c.x_dm i.df06#c.x_dm ///
	f02 f03 f04 f05 f06 c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d x c.d#c.x F.w, noomitted vce(cluster id)


