use did_exit_6_corner, replace

xtset id year

bysort year: tab w

sort id year

list id year w d4_inf d4_6 d4_5 d5_inf d5_6 d6_inf in 133/168, sep(6)

list id year w d4_inf d4_6 d4_5 d5_inf d5_6 d6_inf in 91/126, sep(6)

* Demean the covariate by cohort pairs (g,h). Makes the Poisson coefficients
* on the treatment dummies easier to interpret:

qui sum x if d4_inf
gen x_dm4_inf = x - r(mean)
qui sum x if d4_5
gen x_dm4_5 = x - r(mean)
qui sum x if d4_6
gen x_dm4_6 = x - r(mean)
qui sum x if d5_inf
gen x_dm5_inf = x - r(mean)
qui sum x if d5_6
gen x_dm5_6 = x - r(mean)
qui sum x if d6_inf
gen x_dm6_inf = x - r(mean)

* Define treatment indicators for each cohort pair and separately for each
* calendar time. These are time-varying indicators:
	
gen d4inf4 = d4_inf*f04
gen d4inf5 = d4_inf*f05
gen d4inf6 = d4_inf*f06
gen d464 = d4_6*f04
gen d465 = d4_6*f05
gen d466 = d4_6*f06
gen d454 = d4_5*f04
gen d455 = d4_5*f05
gen d456 = d4_5*f06
gen d5inf5 = d5_inf*f05
gen d5inf6 = d5_inf*f06
gen d565 = d5_6*f05
gen d566 = d5_6*f06
gen d6inf6 = d6_inf*f06

* Compute weights for weighted static and dynamic effects, 
* where only units in treatment are included:

sum d4_inf if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6 + d6_inf)
scalar omega4_inf_0 = r(mean)
sum d4_5 if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6 + d6_inf)
scalar omega4_5_0 = r(mean)
sum d4_6 if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6 + d6_inf)
scalar omega4_6_0 = r(mean)
sum d5_inf if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6 + d6_inf)
scalar omega5_inf_0 = r(mean)
sum d5_6 if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6 + d6_inf)
scalar omega5_6_0 = r(mean)
sum d6_inf if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6 + d6_inf)
scalar omega6_inf_0 = r(mean)

sum d4_inf if (d4_inf + d4_6 + d5_inf)
scalar omega4_inf_1 = r(mean)
sum d4_6 if (d4_inf + d4_6 + d5_inf)
scalar omega4_6_1 = r(mean)
sum d5_inf if (d4_inf + d4_6 + d5_inf)
scalar omega5_inf_1 = r(mean)

poisson y i.d4inf4 i.d4inf5 i.d4inf6 i.d464 i.d465 i.d466 i.d454 i.d455 i.d456 i.d5inf5 i.d5inf6 i.d565 i.d566 i.d6inf6 ///
	i.d4inf4#c.x_dm4_inf i.d4inf5#c.x_dm4_inf i.d4inf6#c.x_dm4_inf i.d464#c.x_dm4_6 ///
	i.d465#c.x_dm4_6 i.d466#c.x_dm4_6 i.d454#c.x_dm4_5 i.d455#c.x_dm4_5 i.d456#c.x_dm4_5 ///
	i.d5inf5#c.x_dm5_inf i.d5inf6#c.x_dm5_inf i.d565#c.x_dm5_6 i.d566#c.x_dm5_6 i.d6inf6#c.x_dm6_inf ///
	i.year i.year#c.x ///
	d4_inf d4_5 d4_6 d5_inf d5_6 d6_inf x ///
	c.d4_inf#c.x c.d4_5#c.x c.d4_6#c.x c.d5_inf#c.x c.d5_6#c.x c.d6_inf#c.x, vce(cluster id)
estimates store poisson_did

margins, dydx(d4inf4) subpop(if d4inf4 == 1) vce(uncond) post
scalar tau4inf4 = _b[1.d4inf4]
di tau4inf4
estimates restore poisson_did
margins, dydx(d4inf5) subpop(if d4inf5 == 1) vce(uncond) post
scalar tau4inf5 = _b[1.d4inf5]
estimates restore poisson_did
margins, dydx(d4inf6) subpop(if d4inf6 == 1) vce(uncond) post
scalar tau4inf6 = _b[1.d4inf6]
estimates restore poisson_did
margins, dydx(d464) subpop(if d464 == 1) vce(uncond) post
scalar tau464 = _b[1.d464]
estimates restore poisson_did
margins, dydx(d465) subpop(if d465 == 1) vce(uncond) post
scalar tau465 = _b[1.d465]
estimates restore poisson_did
margins, dydx(d466) subpop(if d466 == 1) vce(uncond) post
scalar tau466 = _b[1.d466]
estimates restore poisson_did
margins, dydx(d454) subpop(if d454 == 1) vce(uncond) post
scalar tau454 = _b[1.d454]
estimates restore poisson_did
margins, dydx(d455) subpop(if d455 == 1) vce(uncond) post
scalar tau455 = _b[1.d455]
estimates restore poisson_did
margins, dydx(d456) subpop(if d456 == 1) vce(uncond) post
scalar tau456 = _b[1.d456]
estimates restore poisson_did
margins, dydx(d5inf5) subpop(if d5inf5 == 1) vce(uncond) post
scalar tau5inf5 = _b[1.d5inf5]
estimates restore poisson_did
margins, dydx(d5inf6) subpop(if d5inf6 == 1) vce(uncond) post
scalar tau5inf6 = _b[1.d5inf6]
estimates restore poisson_did
margins, dydx(d565) subpop(if d565 == 1) vce(uncond) post
scalar tau565 = _b[1.d565]
estimates restore poisson_did
margins, dydx(d566) subpop(if d566 == 1) vce(uncond) post
scalar tau566 = _b[1.d566]
estimates restore poisson_did
margins, dydx(d6inf6) subpop(if d6inf6 == 1) vce(uncond) post
scalar tau6inf6 = _b[1.d6inf6]
estimates restore poisson_did

lincom omega4_inf_0*_b[1.d4inf4] +  omega4_5_0*_b[1.d454] + omega4_6_0*_b[1.d464] ///
	+ omega5_inf_0*_b[1.d5inf5] + omega5_6_0*_b[1.d565] + omega6_inf_0*_b[1.d6inf6]
	
* Weighted dynamic effect, one period:
lincom omega4_inf_1*_b[1.d4inf5] + omega4_6_1*_b[1.d465]+ omega5_inf_1*_b[1.d5inf6]

* Dynamic effect, two periods:
lincom _b[1.d4inf6]

/*
	
margins, dydx(d4inf4) subpop(if d4inf4 == 1) noestimcheck vce(uncond) post
estimates store  
margins, dydx(d4inf5) subpop(if d4inf5 == 1) noestimcheck vce(uncond)
margins, dydx(d4inf6) subpop(if d4inf6 == 1) noestimcheck vce(uncond)
margins, dydx(d464) subpop(if d464 == 1) noestimcheck vce(uncond)
margins, dydx(d465) subpop(if d465 == 1) noestimcheck vce(uncond)
margins, dydx(d466) subpop(if d466 == 1) noestimcheck vce(uncond)
margins, dydx(d454) subpop(if d454 == 1) noestimcheck vce(uncond)
margins, dydx(d455) subpop(if d455 == 1) noestimcheck vce(uncond)
margins, dydx(d456) subpop(if d456 == 1) noestimcheck vce(uncond)
margins, dydx(d5inf5) subpop(if d5inf5 == 1) noestimcheck vce(uncond)
margins, dydx(d5inf6) subpop(if d5inf6 == 1) noestimcheck vce(uncond)
margins, dydx(d565) subpop(if d565 == 1) noestimcheck vce(uncond)
margins, dydx(d566) subpop(if d566 == 1) noestimcheck vce(uncond)
margins, dydx(d6inf6) subpop(if d6inf6 == 1) noestimcheck vce(uncond)

*/

	
* Weighted averages of the proportionate effects:

qui poisson y i.d4inf4 i.d4inf5 i.d4inf6 i.d464 i.d465 i.d466 i.d454 i.d455 i.d456 i.d5inf5 i.d5inf6 i.d565 i.d566 i.d6inf6 ///
	i.d4inf4#c.x_dm4_inf i.d4inf5#c.x_dm4_inf i.d4inf6#c.x_dm4_inf i.d464#c.x_dm4_6 ///
	i.d465#c.x_dm4_6 i.d466#c.x_dm4_6 i.d454#c.x_dm4_5 i.d455#c.x_dm4_5 i.d456#c.x_dm4_5 ///
	i.d5inf5#c.x_dm5_inf i.d5inf6#c.x_dm5_inf i.d565#c.x_dm5_6 i.d566#c.x_dm5_6 i.d6inf6#c.x_dm6_inf ///
	i.year i.year#c.x ///
	d4_inf d4_5 d4_6 d5_inf d5_6 d6_inf x ///
	c.d4_inf#c.x c.d4_5#c.x c.d4_6#c.x c.d5_inf#c.x c.d5_6#c.x c.d6_inf#c.x, vce(cluster id)
	
lincom omega4_inf_0*_b[1.d4inf4] +  omega4_5_0*_b[1.d454] + omega4_6_0*_b[1.d464] ///
	+ omega5_inf_0*_b[1.d5inf5] + omega5_6_0*_b[1.d565] + omega6_inf_0*_b[1.d6inf6]
	
* Weighted dynamic effect, one period:
lincom omega4_inf_1*_b[1.d4inf5] + omega4_6_1*_b[1.d465]+ omega5_inf_1*_b[1.d5inf6]

* Dynamic effect, two periods:
lincom _b[1.d4inf6]

* Now use the margins trick over subpopulations to obtain the weighted effects
* and the proper standard errors:

poisson y i.w#c.d4inf4 i.w#c.d4inf5 i.w#c.d4inf6 i.w#c.d464 i.w#c.d465 c.d466 i.w#c.d454 c.d455 c.d456 ///
	i.w#c.d5inf5 i.w#c.d5inf6 i.w#c.d565 c.d566 i.w#c.d6inf6 ///
	i.w#c.d4inf4#c.x_dm4_inf i.w#c.d4inf5#c.x_dm4_inf i.w#c.d4inf6#c.x_dm4_inf i.w#c.d464#c.x_dm4_6 ///
	i.w#c.d465#c.x_dm4_6 c.d466#c.x_dm4_6 i.w#c.d454#c.x_dm4_5 c.d455#c.x_dm4_5 c.d456#c.x_dm4_5 ///
	i.w#c.d5inf5#c.x_dm5_inf i.w#c.d5inf6#c.x_dm5_inf i.w#c.d565#c.x_dm5_6 c.d566#c.x_dm5_6 i.w#c.d6inf6#c.x_dm6_inf ///
	i.year i.year#c.x ///
	d4_inf d4_5 d4_6 d5_inf d5_6 d6_inf x ///
	c.d4_inf#c.x c.d4_5#c.x c.d4_6#c.x c.d5_inf#c.x c.d5_6#c.x c.d6_inf#c.x, vce(cluster id)
	
gen exp0 = d4inf4 + d464 + d454 + d5inf5 + d565 + d6inf6
gen exp1 = d4inf5 + d465 + d5inf6
gen exp2 = d4inf6

* First the proportionate ATTs aggregated by exposure time -- that is, the 
* ATTs on the log of the expectation:

margins, eydx(w) subpop(if exp0 == 1) noestimcheck vce(uncond)
margins, eydx(w) subpop(if exp1 == 1) noestimcheck vce(uncond)
margins, eydx(w) subpop(if exp2 == 1) noestimcheck vce(uncond)

* Now the ATTs on the mean:
	
margins, dydx(w) subpop(if exp0 == 1) noestimcheck vce(uncond)
margins, dydx(w) subpop(if exp1 == 1) noestimcheck vce(uncond)
margins, dydx(w) subpop(if exp2 == 1) noestimcheck vce(uncond)

* Can also aggregate the effects by time out of treatment by defining a dummy
* variable that is one for units that have been treated but are now out of
* treatment:

gen pot = d466 + d455 + d456 + d566

poisson y i.w#c.d4inf4 i.w#c.d4inf5 i.w#c.d4inf6 i.w#c.d464 i.w#c.d465 i.pot#c.d466 i.w#c.d454 ///
	i.pot#c.d455 i.pot#c.d456 i.w#c.d5inf5 i.w#c.d5inf6 i.w#c.d565 i.pot#c.d566 i.w#c.d6inf6 ///
	i.w#c.d4inf4#c.x_dm4_inf i.w#c.d4inf5#c.x_dm4_inf i.w#c.d4inf6#c.x_dm4_inf i.w#c.d464#c.x_dm4_6 ///
	i.w#c.d465#c.x_dm4_6 i.pot#c.d466#c.x_dm4_6 i.w#c.d454#c.x_dm4_5 i.pot#c.d455#c.x_dm4_5 i.pot#c.d456#c.x_dm4_5 ///
	i.w#c.d5inf5#c.x_dm5_inf i.w#c.d5inf6#c.x_dm5_inf i.w#c.d565#c.x_dm5_6 i.pot#c.d566#c.x_dm5_6 i.w#c.d6inf6#c.x_dm6_inf ///
	i.year i.year#c.x ///
	d4_inf d4_5 d4_6 d5_inf d5_6 d6_inf x ///
	c.d4_inf#c.x c.d4_5#c.x c.d4_6#c.x c.d5_inf#c.x c.d5_6#c.x c.d6_inf#c.x, vce(cluster id)
	
gen out1 = d466 + d455 + d566
gen out2 = d456

margins, eydx(pot) subpop(if out1 == 1) noestimcheck vce(uncond)
margins, eydx(pot) subpop(if out2 == 1) noestimcheck vce(uncond)

margins, dydx(pot) subpop(if out1 == 1) noestimcheck vce(uncond)
margins, dydx(pot) subpop(if out2 == 1) noestimcheck vce(uncond)

* Can also extend to an ES method, where all cohort dummmies are interacted
* with pre-treatment indicators.

gen prt = 0
replace prt = 1 if d4_inf & (year <= 2003)
replace prt = 1 if d4_6 & (year <= 2003)
replace prt = 1 if d4_5 & (year <= 2003)
replace prt = 1 if d5_inf & (year <= 2004)
replace prt = 1 if d5_6 & (year <= 2004)
replace prt = 1 if d6_inf & (year <= 2005)

gen d4inf1 = d4_inf*f01
gen d4inf2 = d4_inf*f02
gen d461 = d4_6*f01
gen d462 = d4_6*f02
gen d451 = d4_5*f01
gen d452 = d4_5*f02
gen d5inf1 = d5_inf*f01
gen d5inf2 = d5_inf*f02
gen d5inf3 = d5_inf*f03
gen d561 = d5_6*f01
gen d562 = d5_6*f02
gen d563 = d5_6*f03
gen d6inf1 = d6_inf*f01
gen d6inf2 = d6_inf*f02
gen d6inf3 = d6_inf*f03
gen d6inf4 = d6_inf*f04

gen pre2 = d4inf2 + d462 + d452 + d5inf3 + d563 + d6inf4
gen pre3 = d4inf1 + d461 + d451 + d5inf2 + d562 + d6inf3
gen pre4 = d5inf1 + d561 + d6inf2
gen pre5 = d6inf1

poisson y i.prt#c.d4inf1 i.prt#c.d4inf2 i.prt#c.d461 i.prt#c.d462 i.prt#c.d451 i.prt#c.d452 ///
	i.prt#c.d5inf1 i.prt#c.d5inf2 i.prt#c.d5inf3 i.prt#c.d561 i.prt#c.d562 i.prt#c.d563 ///
	i.prt#c.d6inf1 i.prt#c.d6inf2 i.prt#c.d6inf3 i.prt#c.d6inf4 ///
	i.w#c.d4inf4 i.w#c.d4inf5 i.w#c.d4inf6 i.w#c.d464 i.w#c.d465 i.w#c.d454 i.w#c.d5inf5 i.w#c.d5inf6 i.w#c.d565 i.w#c.d6inf6 ///
	i.pot#c.d455 i.pot#c.d456 i.pot#c.d466 i.pot#c.d566 ///
	i.prt#c.d4inf1#c.x_dm4_inf i.prt#c.d4inf2#c.x_dm4_inf i.prt#c.d461#c.x_dm4_6 i.prt#c.d462#c.x_dm4_6 i.prt#c.d451#c.x_dm4_5 i.prt#c.d452#c.x_dm4_5 ///
	i.prt#c.d5inf1#c.x_dm5_inf i.prt#c.d5inf2#c.x_dm5_inf i.prt#c.d5inf3#c.x_dm5_inf i.prt#c.d561#c.x_dm5_6 i.prt#c.d562#c.x_dm5_6 i.prt#c.d563#c.x_dm5_6 ///
	i.prt#c.d6inf1#c.x_dm6_inf i.prt#c.d6inf2#c.x_dm6_inf i.prt#c.d6inf3#c.x_dm6_inf i.prt#c.d6inf4#c.x_dm6_inf ///
	i.w#c.d4inf4#c.x_dm4_inf i.w#c.d4inf5#c.x_dm4_inf i.w#c.d4inf6#c.x_dm4_inf i.w#c.d464#c.x_dm4_6 ///
	i.w#c.d465#c.x_dm4_6 i.pot#c.d466#c.x_dm4_6 i.w#c.d454#c.x_dm4_5 ///
	i.w#c.d5inf5#c.x_dm5_inf i.w#c.d5inf6#c.x_dm5_inf i.w#c.d565#c.x_dm5_6 i.w#c.d6inf6#c.x_dm6_inf ///
	i.pot#c.d455#c.x_dm4_5 i.pot#c.d456#c.x_dm4_5 i.pot#c.d566#c.x_dm5_6  ///
	i.year i.year#c.x ///
	d4_inf d4_5 d4_6 d5_inf d5_6 d6_inf x ///
	c.d4_inf#c.x c.d4_5#c.x c.d4_6#c.x c.d5_inf#c.x c.d5_6#c.x c.d6_inf#c.x, vce(cluster id)
	
estimates store poisson_did

margins, dydx(prt) subpop(if pre5 == 1) noestimcheck vce(uncond) post
estimates store att_pre5
estimates restore poisson_did
margins, dydx(prt) subpop(if pre4 == 1) noestimcheck vce(uncond) post
estimates store att_pre4
estimates restore poisson_did
margins, dydx(prt) subpop(if pre3 == 1) noestimcheck vce(uncond) post
estimates store att_pre3
estimates restore poisson_did
margins, dydx(prt) subpop(if pre2 == 1) noestimcheck vce(uncond) post
estimates store att_pre2
estimates restore poisson_did
gen zero = 0
reg zero
estimates store att_pre1
estimates restore poisson_did

margins, dydx(w) subpop(if exp0 == 1) noestimcheck vce(uncond) post
estimates store att_0
estimates restore poisson_did
margins, dydx(w) subpop(if exp1 == 1) noestimcheck vce(uncond) post
estimates store att_1
estimates restore poisson_did
margins, dydx(w) subpop(if exp2 == 1) noestimcheck vce(uncond) post
estimates store att_2
estimates restore poisson_did

margins, dydx(pot) subpop(if out1 == 1) noestimcheck vce(uncond) post
estimates store att_post1
estimates restore poisson_did
margins, dydx(pot) subpop(if out2 == 1) noestimcheck vce(uncond) post
estimates store att_post2
estimates restore poisson_did

* margins, dydx(w) subpop(if w == 1) noestimcheck vce(uncond)

coefplot (att_pre5, rename(1.prt = "-5") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_pre4, rename(1.prt = "-4") mcolor(black)  ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_pre3, rename(1.prt = "-3") mcolor(black)  ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_pre2, rename(1.prt = "-2") mcolor(black)  ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_pre1, rename(_cons = "-1") mcolor(black)) ///
			(att_0, rename(1.w = "0") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_1, rename(1.w = "1") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_2, rename(1.w = "2") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))), yline(0) vertical ///
			title("Weighted Effects by Exposure Length") ///
			xtitle("Exposure Length") ytitle("Weighted Treatment Effects") nokey
			
coefplot (att_pre5, rename(1.prt = "-5") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_pre4, rename(1.prt = "-4") mcolor(black)  ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_pre3, rename(1.prt = "-3") mcolor(black)  ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_pre2, rename(1.prt = "-2") mcolor(black)  ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_pre1, rename(_cons = "-1") mcolor(black)) ///
			(att_0, rename(1.w = "0") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_1, rename(1.w = "1") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_2, rename(1.w = "2") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_post1, rename(1.pot = "1") mcolor(black) ciopts(lcolor(green) recast(rcap) lwidth(0.5))) ///
			(att_post2, rename(1.pot = "2") mcolor(black) ciopts(lcolor(green) recast(rcap) lwidth(0.5))), ///
			yline(0) vertical title("Weighted Effects by Exposure Length") ///
			xtitle("Exposure Length") ytitle("Weighted Treatment Effects") nokey

/*

* Now the deCDH method. They compute a different weighted average. A unit is
* considered in treatment for, say, two periods even if the treatment ended
* in an earlier period.

* Time constant controls drop out because of differencing:

* did_multiplegt y id year w
* did_multiplegt y id year w, robust_dynamic
did_multiplegt y id year w, robust_dynamic dynamic(2) breps(100)
* did_multiplegt y id year w, robust_dynamic dynamic(2) breps(100) controls(x)

gen f02_x = f02*x
gen f03_x = f03*x
gen f04_x = f04*x
gen f05_x = f05*x
gen f06_x = f06*x
did_multiplegt y id year w, robust_dynamic dynamic(2) breps(100) ///
	controls(x f02_x f03_x f04_x f05_x f06_x)
	
* deCDH include all treated units in a given starting cohort even if 
* the treatment has gone away. The static effects are computed the same
* as before because all treated units are, of course, treated for at 
* least one period. But the dynamic weights are different.

* Static effect:

di omega4_inf_0*tau4inf4 +  omega4_5_0*tau454 + omega4_6_0*tau464 ///
	+ omega5_inf_0*tau5inf5 + omega5_6_0*tau565 + omega6_inf_0*tau6inf6
sum d4_inf if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6)
scalar omega4_inf_1_deCDH = r(mean)
sum d4_5 if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6)
scalar omega4_5_1_deCDH = r(mean)
sum d4_6 if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6)
scalar omega4_6_1_deCDH = r(mean)
sum d5_inf if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6)
scalar omega5_inf_1_deCDH = r(mean)
sum d5_6 if (d4_inf + d4_5 + d4_6 + d5_inf + d5_6)
scalar omega5_6_1_deCDH = r(mean)

* The lag one deCDH SATT:

di omega4_inf_1_deCDH*tau4inf5 + omega4_5_1_deCDH*tau455 /// 
	+ omega4_6_1_deCDH*tau465 + omega5_inf_1_deCDH*tau5inf6 + omega5_6_1_deCDH*tau566
	
* The lag two  deCDH SATT:
	
sum d4_inf if (d4_inf + d4_5 + d4_6)
scalar omega4_inf_2_deCDH = r(mean)
sum d4_5 if (d4_inf + d4_5 + d4_6)
scalar omega4_5_2_deCDH = r(mean)
sum d4_6 if (d4_inf + d4_5 + d4_6)
scalar omega4_6_2_deCDH = r(mean)

di omega4_inf_2_deCDH*tau4inf6 + omega4_5_2_deCDH*tau456 /// 
	+ omega4_6_2_deCDH*tau466

* The deCDH definitions of the dynamic ATTs by aggregating the ETWFE estimates:

qui reg y d4inf4 d4inf5 d4inf6 d464 d465 d466 d454 d455 d456 d5inf5 d5inf6 d565 d566 d6inf6 ///
	c.d4inf4#c.x_dm4_inf c.d4inf5#c.x_dm4_5 c.d4inf6#c.x_dm4_6 c.d464#c.x_dm4_6 ///
	c.d465#c.x_dm4_6 c.d466#c.x_dm4_6 c.d454#c.x_dm4_5 c.d455#c.x_dm4_5 c.d456#c.x ///
	c.d5inf5#c.x_dm5_inf c.d5inf6#c.x_dm5_inf c.d565#c.x_dm5_6 c.d566#c.x_dm5_6 c.d6inf6#c.x_dm6_inf ///
	i.year i.year#c.x ///
	d4_inf d4_5 d4_6 d5_inf d5_6 d6_inf x ///
	c.d4_inf#c.x c.d4_5#c.x c.d4_6#c.x c.d5_inf#c.x c.d5_6#c.x c.d6_inf#c.x, vce(cluster id)

lincom omega4_inf_0*_b[d4inf4] + omega4_5_0*_b[d454] + omega4_6_0*_b[d464] ///
	+ omega5_inf_0*_b[d5inf5] + omega5_6_0*_b[d565] + omega6_inf_0*_b[d6inf6]
lincom omega4_inf_1_deCDH*_b[d4inf5] + omega4_5_1_deCDH*_b[d455] + omega4_6_1_deCDH*_b[d465] ///
	+ omega5_inf_1_deCDH*_b[d5inf6] + omega5_6_1_deCDH*_b[d566]
lincom omega4_inf_2_deCDH*_b[d4inf6] + omega4_5_2_deCDH*_b[d456] + omega4_6_2_deCDH*_b[d466]

* log close
