use did_staggered_6, clear

xtset id year

list id year y w dinf d4 d5 d6 in 31/60, sep(6)

* Compute cohort shares:

tab dinf if f01
tab d4 if f01
tab d5 if f01
tab d6 if f01

sum x if d4
gen x_dm4 = x - r(mean)
sum x if d5
gen x_dm5 = x - r(mean)
sum x if d6
gen x_dm6 = x - r(mean)

* Compute the SATTs by cohort/year. These are the targets for this
* data set.

sum te4 if d4 & f04
scalar tau44 = r(mean)
sum te4 if d4 & f05
scalar tau45 = r(mean)
sum te4 if d4 & f06
scalar tau46 = r(mean)
sum te5 if d5 & f05
scalar tau55 = r(mean)
sum te5 if d5 & f06
scalar tau56 = r(mean)
sum te6 if d6 & f06
scalar tau66 = r(mean)

* The "lags" only (extended TWFE estimator) without controls:

xthdidregress twfe (y) (w), group(id)
estat aggregation, dynamic graph
estat aggregation

gen first_treat = 0
replace first_treat = 2004 if d4
replace first_treat = 2005 if d5
replace first_treat = 2006 if d6

jwdid y x, ivar(id) tvar(year) gvar(first_treat)
estat event
estat plot
estat simple

gen d4f01 = d4*f01
gen d4f02 = d4*f02
gen d4f03 = d4*f03
gen d4f04 = d4*f04
gen d4f05 = d4*f05
gen d4f06 = d4*f06
gen d5f01 = d5*f01
gen d5f02 = d5*f02
gen d5f03 = d5*f03
gen d5f04 = d5*f04
gen d5f05 = d5*f05
gen d5f06 = d5*f06
gen d6f01 = d6*f01
gen d6f02 = d6*f02
gen d6f03 = d6*f03
gen d6f04 = d6*f04
gen d6f05 = d6*f05
gen d6f06 = d6*f06

* POLS without pre-treatment indicators. Reproduces xthdidregress twfe and
* jwdid.

reg y d4f04 d4f05 d4f06 d5f05 d5f06 d6f06 d4 d5 d6 i.year, vce(cluster id)

/*

* Event study regression, no controls. The TWFE version is the same, due to
* Sun and Abraham (2021, Journal of Econometrics):

xtreg y d4f01 d4f02 d4f04 d4f05 d4f06 d5f01 d5f02 d5f03 d5f05 d5f06 ///
	d6f01 d6f02 d6f03 d6f04 d6f06 i.year, fe vce(cluster id)

* POLS with cohort dummmies [Wooldridge (2021, 2023)]. Coefficients on 
* d4, d5, d6 show nonrandom selection into treatment cohort:

reg y d4f01 d4f02 d4f04 d4f05 d4f06 d5f01 d5f02 d5f03 d5f05 d5f06 ///
	d6f01 d6f02 d6f03 d6f04 d6f06 d4 d5 d6 i.year, vce(cluster id)
	
* ES test for pre-trends:
test d4f01 d4f02 d5f01 d5f02 d5f03 d6f01 d6f02 d6f03 d6f04

* RE is also the same:

xtreg y d4f01 d4f02 d4f04 d4f05 d4f06 d5f01 d5f02 d5f03 d5f05 d5f06 ///
	d6f01 d6f02 d6f03 d6f04 d6f06 d4 d5 d6 i.year, re vce(cluster id)
	
qui reg y d4f01 d4f02 d4f04 d4f05 d4f06 d5f01 d5f02 d5f03 d5f05 d5f06 ///
	d6f01 d6f02 d6f03 d6f04 d6f06 d4 d5 d6 i.year, vce(cluster id)	

* Weighted estimates for ES graph. "m" stands for "minus":

* 0 weights
sum d4 if (d4 + d5 + d6)
scalar omega4_0 = r(mean)
sum d5 if (d4 + d5 + d6)
scalar omega5_0 = r(mean)
sum d6 if (d4 + d5 + d6)
scalar omega6_0 = r(mean)

* +1 weights
sum d4 if (d4 + d5)
scalar omega4_1 = r(mean)
sum d5 if (d4 + d5)
scalar omega5_1 = r(mean)

* -4 weights:
qui sum d5 if (d5 + d6)
scalar omega5_m4 = r(mean)
qui sum d6 if (d5 + d6)
scalar omega6_m4 = r(mean)

* -3 weights:
scalar omega4_m3 = omega4_0
scalar omega5_m3 = omega5_0
scalar omega6_m3 = omega6_0

* -2 weights:
scalar omega4_m2 = omega4_0
scalar omega5_m2 = omega5_0
scalar omega6_m2 = omega6_0

* Obtain the weighted estimates by exposure length for a single ES graph.
* The standard errors do not account for the sampling variation in the 
* weights:

* -5 effect:
lincom d6f01
* -4 effect:
lincom omega5_m4*d5f01 + omega6_m4*d6f02
* -3 effect:
lincom omega4_m3*d4f01 + omega5_m3*d5f02 + omega6_m3*d6f03
* -2 effect:
lincom omega4_m2*d4f02 + omega5_m2*d5f03 + omega6_m2*d6f04
* 0 effect (immediate effect):
lincom omega4_0*d4f04 + omega5_0*d5f05 + omega6_0*d6f06
* One-period effect:
lincom omega4_1*d4f05 + omega5_1*d5f06
* Two-period effect:
lincom d4f06

* Easy to get the weighted effects and the proper standard errors.
* Need to explicitly include the time-varying indicator and also the
* non-treatment indicator:

*/

* The user-written eventstudyinteract implements the Sun and Abraham (2021) 
* TWFE approach and calculates the weights internally. Without controls it 
* reproduces the above long regression and aggregating the treatment
* effects by exposure time. It doesn't include controls flexibly. 
* Time constant controls drop out because they are included only additively.

replace first_treat = . if first_treat == 0
gen never_treat = first_treat == .

* Generate the relative year variable:

gen ry = 0 if never_treat
replace ry = year - first_treat if first_treat != .

tab ry

forvalues k = 5(-1)1 {
           gen g_`k' = ry == -`k'
        }
forvalues k = 0/2 {
             gen g`k' = ry == `k'
        }

eventstudyinteract y g_5 g_4 g_3 g_2 g0 g1 g2, cohort(first_treat) ///
	control_cohort(never_treat) absorb(i.id i.year) vce(cluster id)

matrix C = e(b_iw)
matrix list C
mata st_matrix("A",sqrt(diagonal(st_matrix("e(V_iw)"))))
matrix C = C \ A'
matrix list C

coefplot matrix(C[1]), se(C[2]) yline(0) vertical xlabel(,angle(45)) recast(line)

* csdid without controls reproduces the eventstudyinteract:
replace first_treat = 0 if first_treat == .
csdid y, ivar(id) time(year) gvar(first_treat) method(reg) long2
estat event
csdid_plot

* csdid y, ivar(id) time(year) gvar(first_treat) method(reg) long2 wboot replace rseed(123)

/*

* Following reproduces Sun-Abraham but obtains standard errors that
* account for sampling errors in the weights. Also, the graph 
* explicitly imposes the normalization of setting the period -1 ATT to
* zero.

gen nw = 1 - w

* Using c.nw, c.w makes the output look better. Using 1.nw, 1.w does, too.
* But both should be avoided for nonlinear models as it means to treat nw, 
* w as continuous variables.

reg y c.nw#c.d4f01 c.nw#c.d4f02 c.w#c.d4f04 c.w#c.d4f05 c.w#c.d4f06 ///
	c.nw#c.d5f01 c.nw#c.d5f02 c.nw#c.d5f03 c.w#c.d5f05 c.w#c.d5f06 ///
	c.nw#c.d6f01 c.nw#c.d6f02 c.nw#c.d6f03 c.nw#c.d6f04 c.w#c.d6f06 ///
	c.d4 c.d5 c.d6 i.year, vce(cluster id)
estimates store reg_did
	
* Generate exposure time dummies:

gen exp0 = d4f04 + d5f05 + d6f06
gen exp1 = d4f05 + d5f06
gen exp2 = d4f06

* Pre-treatment exposure times:

gen expm1 = d4f03 + d5f04 + d6f05
gen expm2 = d4f02 + d5f03 + d6f04
gen expm3 = d4f01 + d5f02 + d6f03
gen expm4 = d5f01 + d6f02
gen expm5 = d6f01

margins, dydx(nw) subpop(if expm5 == 1) vce(uncond) post
estimates store att_m5
estimates restore reg_did
margins, dydx(nw) subpop(if expm4 == 1) vce(uncond) post
estimates store att_m4
estimates restore reg_did
margins, dydx(nw) subpop(if expm3 == 1) vce(uncond) post
estimates store att_m3
estimates restore reg_did
margins, dydx(nw) subpop(if expm2 == 1) vce(uncond) post
estimates store att_m2
gen zero = 0
reg zero
estimates store att_m1
estimates restore reg_did
margins, dydx(w) subpop(if exp0 == 1) vce(uncond) post
estimates store att_0
estimates restore reg_did
margins, dydx(w) subpop(if exp1 == 1) vce(uncond) post
estimates store att_1
estimates restore reg_did
margins, dydx(w) subpop(if exp2 == 1) vce(uncond) post
estimates store att_2

coefplot (att_m5, rename(nw="-5") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m4, rename(nw="-4") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m3, rename(nw="-3") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m2, rename(nw="-2") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m1, rename(_cons ="-1") mcolor(black)) ///
			(att_0, rename(w="0") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_1, rename(w="1") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_2, rename(w="2") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) , yline(0) vertical ///
			title("Weighted Effects by Exposure Length") ///
			xtitle("Exposure Length") ytitle("Weighted Treatment Effects") nokey
			
graph save did_staggered_6_event_nocontrol, replace

/*

* Reproduce the ES estimates (from the full regression above) using 2 x 2 DiDs.
* The controls consist of the NT group.

reg y c.d4f01 c.d4 i.year if (d4 | dinf) & (f03 | f01), vce(cluster id)
reg y c.d4f02 c.d4 i.year if (d4 | dinf) & (f03 | f02), vce(cluster id)
reg y c.d4f04 c.d4 i.year if (d4 | dinf) & (f03 | f04), vce(cluster id)
reg y c.d4f05 c.d4 i.year if (d4 | dinf) & (f03 | f05), vce(cluster id)
reg y c.d4f06 c.d4 i.year if (d4 | dinf) & (f03 | f06), vce(cluster id)

reg y c.d5f01 c.d5 i.year if (d5 | dinf) & (f04 | f01), vce(cluster id)
reg y c.d5f02 c.d5 i.year if (d5 | dinf) & (f04 | f02), vce(cluster id)
reg y c.d5f03 c.d5 i.year if (d5 | dinf) & (f04 | f03), vce(cluster id)
reg y c.d5f05 c.d5 i.year if (d5 | dinf) & (f04 | f05), vce(cluster id)
reg y c.d5f06 c.d5 i.year if (d5 | dinf) & (f04 | f06), vce(cluster id)

reg y c.d6f01 c.d6 i.year if (d6 | dinf) & (f05 | f01), vce(cluster id)
reg y c.d6f02 c.d6 i.year if (d6 | dinf) & (f05 | f02), vce(cluster id)
reg y c.d6f03 c.d6 i.year if (d6 | dinf) & (f05 | f03), vce(cluster id)
reg y c.d6f04 c.d6 i.year if (d6 | dinf) & (f05 | f04), vce(cluster id)
reg y c.d6f06 c.d6 i.year if (d6 | dinf) & (f05 | f06), vce(cluster id)

*/


* ES test for pre-trends is the same if we use a different base period, 
* but estimates are different. For example, below, the first period is the 
* reference period for every cohort:

reg y d4f02 d4f03 d4f04 d4f05 d4f06 d5f02 d5f03 d5f04 d5f05 d5f06 ///
	d6f02 d6f03 d6f04 d6f05 d6f06 d4 d5 d6 i.year, vce(cluster id)
	
test d4f02 d4f03 d5f02 d5f03 d5f04 d6f02 d6f03 d6f04 d6f05

*/

/*

xthdidregress twfe (y x) (w), group(id)
estat aggregation, dynamic graph
estat aggregation

*/

* The "lags only" (extended TWFE) estimator:

jwdid y x, ivar(id) tvar(year) gvar(first_treat)
estat event
estat plot
estat simple

* Now add the control, x to the ES. For just the ATTs and placebo effects, easiest
* to use csdid:

csdid y x, ivar(id) time(year) gvar(first_treat) method(reg) long2
estat pretrend
estat event
csdid_plot
estat simple

* CS (2021) using the default DR estimator:
csdid y x, ivar(id) time(year) gvar(first_treat) long2
estat event

/*

xthdidregress ra (y x) (w), group(id)
estat aggregation, dynamic graph
estat aggregation

*/

* csdid y x, ivar(id) time(year) gvar(first_treat) method(reg) notyet long2

* To reproduce Callaway-Sant'Anna 2 x 2 DiD regressions using the never treated units as 
* controls and interact covariates with everything, including the pre-treatment indicators. 
* Technically, this allows violation of parallel trends before the
* intervention but assumes CPT holds just as the intervention begins.

qui reg y c.nw#c.d4f01 c.nw#c.d4f02 c.w#c.d4f04 c.w#c.d4f05 c.w#c.d4f06 ///
	c.nw#c.d5f01 c.nw#c.d5f02 c.nw#c.d5f03 c.w#c.d5f05 c.w#c.d5f06 ///
	c.nw#c.d6f01 c.nw#c.d6f02 c.nw#c.d6f03 c.nw#c.d6f04 c.w#c.d6f06 ///
	c.nw#c.d4f01#c.x_dm4 c.nw#c.d4f02#c.x_dm4 c.w#c.d4f04#c.x_dm4 c.w#c.d4f05#c.x_dm4 c.w#c.d4f06#c.x_dm4 ///
	c.nw#c.d5f01#c.x_dm5 c.nw#c.d5f02#c.x_dm5 c.nw#c.d5f03#c.x_dm5 c.w#c.d5f05#c.x_dm5 c.w#c.d5f06#c.x_dm5 ///
	c.nw#c.d6f01#c.x_dm6 c.nw#c.d6f02#c.x_dm6 c.nw#c.d6f03#c.x_dm6 c.nw#c.d6f04#c.x_dm6 c.w#c.d6f06#c.x_dm6 ///
	c.d4 c.d5 c.d6 x c.d4#c.x c.d5#c.x c.d6#c.x ///
	i.year i.year#c.x, vce(cluster id)
estimates store reg_did

margins, dydx(nw) subpop(if expm5 == 1) vce(uncond) post
estimates store att_m5
estimates restore reg_did
margins, dydx(nw) subpop(if expm4 == 1) vce(uncond) post
estimates store att_m4
estimates restore reg_did
margins, dydx(nw) subpop(if expm3 == 1) vce(uncond) post
estimates store att_m3
estimates restore reg_did
margins, dydx(nw) subpop(if expm2 == 1) vce(uncond) post
estimates store att_m2
reg zero
estimates store att_m1
estimates restore reg_did
margins, dydx(w) subpop(if exp0 == 1) vce(uncond) post
estimates store att_0
estimates restore reg_did
margins, dydx(w) subpop(if exp1 == 1) vce(uncond) post
estimates store att_1
estimates restore reg_did
margins, dydx(w) subpop(if exp2 == 1) vce(uncond) post
estimates store att_2

* Single weighted effects both pre- and post-treatment:

estimates restore reg_did
margins, dydx(nw) subpop(if nw == 1) vce(uncond)
margins, dydx(w) subpop(if w == 1) vce(uncond)

/*

coefplot (att_m5, rename(nw="-5") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m4, rename(nw="-4") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m3, rename(nw="-3") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m2, rename(nw="-2") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m1, rename(_cons ="-1") mcolor(black)) ///
			(att_0, rename(w="0") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_1, rename(w="1") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_2, rename(w="2") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) , yline(0) vertical ///
			title("Weighted Effects by Exposure Length") ///
			xtitle("Exposure Length") ytitle("Weighted Treatment Effects") nokey
			
graph save did_staggered_6_event_control, replace

/*

* Equivalently, aggregate with weights. But these SEs don't account for
* sampling error in weights:

reg y c.d4f01 c.d4f02 c.d4f04 c.d4f05 c.d4f06 ///
	c.d5f01 c.d5f02 c.d5f03 c.d5f05 c.d5f06 ///
	c.d6f01 c.d6f02 c.d6f03 c.d6f04 c.d6f06 ///
	c.d4f01#c.x_dm4 c.d4f02#c.x_dm4 c.d4f04#c.x_dm4 c.d4f05#c.x_dm4 c.d4f06#c.x_dm4 ///
	c.d5f01#c.x_dm5 c.d5f02#c.x_dm5 c.d5f03#c.x_dm5 c.d5f05#c.x_dm5 c.d5f06#c.x_dm5 ///
	c.d6f01#c.x_dm6 c.d6f02#c.x_dm6 c.d6f03#c.x_dm6 c.d6f04#c.x_dm6 c.d6f06#c.x_dm6 ///
	c.d4 c.d5 c.d6 x c.d4#c.x c.d5#c.x c.d6#c.x ///
	i.year i.year#c.x, vce(cluster id)
	
test d4f01 d4f02 d5f01 d5f02 d5f03 d6f01 d6f02 d6f03 d6f04

* -5 effect:
lincom d6f01
* -4 effect:
lincom omega5_m4*d5f01 + omega6_m4*d6f02
* -3 effect:
lincom omega4_m3*d4f01 + omega5_m3*d5f02 + omega6_m3*d6f03
* -2 effect:
lincom omega4_m2*d4f02 + omega5_m2*d5f03 + omega6_m2*d6f04
* 0 effect (immediate effect):
lincom omega4_0*d4f04 + omega5_0*d5f05 + omega6_0*d6f06
* One-period effect:
lincom omega4_1*d4f05 + omega5_1*d5f06
* Two-period effect:
lincom d4f06

* Verify get the same estimates on non-treatment variables using control
* observations:

reg y d4f01 d4f02 d5f01 d5f02 d5f03 d6f01 d6f02 d6f03 d6f04 ///
	c.d4f01#c.x_dm4 c.d4f02#c.x_dm4 c.d5f01#c.x_dm5 c.d5f02#c.x_dm5 c.d5f03#c.x_dm5 ///
	c.d6f01#c.x_dm6 c.d6f02#c.x_dm6 c.d6f03#c.x_dm6 c.d6f04#c.x_dm6 ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x ///
	i.year i.year#c.x if w == 0, vce(cluster id)
	
test d4f01 d4f02 d5f01 d5f02 d5f03 d6f01 d6f02 d6f03 d6f04

predict tehat, resid
sum tehat if d4f04
sum tehat if d4f05
sum tehat if d4f06
sum tehat if d5f05
sum tehat if d5f06
sum tehat if d6f06

sum tehat if exp0
sum tehat if exp1
sum tehat if exp2
sum tehat if w

* xthdidregress does the default CS (2021), which does not use the
* period just prior to the intervention as the base period.

xthdidregress ra (y x) (w), group(id)
estat aggregation, dynamic graph
estat aggregation

csdid y x, ivar(id) time(year) gvar(first_treat) method(reg)
estat event
estat simple

* As usual, equivalent to FE, and this gives exactly the same SEs as xthdidregress
* with the "ra" option:

xtreg y d4f01 d4f02 d4f04 d4f05 d4f06 ///
	d5f01 d5f02 d5f03 d5f05 d5f06 ///
	d6f01 d6f02 d6f03 d6f04 d6f06 ///
	c.d4f01#c.x_dm4 c.d4f02#c.x_dm4 c.d4f04#c.x_dm4 c.d4f05#c.x_dm4 c.d4f06#c.x_dm4 ///
	c.d5f01#c.x_dm5 c.d5f02#c.x_dm5 c.d5f03#c.x_dm5 c.d5f05#c.x_dm5 c.d5f06#c.x_dm5 ///
	c.d6f01#c.x_dm6 c.d6f02#c.x_dm6 c.d6f03#c.x_dm6 c.d6f04#c.x_dm6 c.d6f06#c.x_dm6 ///
	i.year i.year#c.x, fe vce(cluster id)
	
*/
	
/*
	
* And RE:
	
xtreg y d4f01 d4f02 d4f04 d4f05 d4f06 ///
	d5f01 d5f02 d5f03 d5f05 d5f06 ///
	d6f01 d6f02 d6f03 d6f04 d6f06 ///
	c.d4f01#c.x_dm4 c.d4f02#c.x_dm4 c.d4f04#c.x_dm4 c.d4f05#c.x_dm4 c.d4f06#c.x_dm4 ///
	c.d5f01#c.x_dm5 c.d5f02#c.x_dm5 c.d5f03#c.x_dm5 c.d5f05#c.x_dm5 c.d5f06#c.x_dm5 ///
	c.d6f01#c.x_dm6 c.d6f02#c.x_dm6 c.d6f03#c.x_dm6 c.d6f04#c.x_dm6 c.d6f06#c.x_dm6 ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x ///
	i.year i.year#c.x, re vce(cluster id)
	
*/
	
* Even creating the the interactions with the controls to allow time-constant
* variables with varying coefficients does not reproduce csdid 
* (equivalently, the very long regression). Plus, the standard errors
* are more than double, and in one case more than triple, the SEs 
* gotten from the VLR or csdid.
	
gen d4f01x = d4f01*x
gen d4f02x = d4f02*x
gen d4f04x = d4f04*x
gen d4f05x = d4f05*x
gen d4f06x = d4f06*x

gen d5f01x = d5f01*x
gen d5f02x = d5f02*x
gen d5f03x = d5f03*x
gen d5f05x = d5f05*x
gen d5f06x = d5f06*x

gen d6f01x = d6f01*x
gen d6f02x = d6f02*x
gen d6f03x = d6f03*x
gen d6f04x = d6f04*x
gen d6f06x = d6f06*x

gen f01x = f01*x
gen f02x = f02*x
gen f03x = f03*x
gen f04x = f04*x
gen f05x = f05*x
gen f06x = f06*x

eventstudyinteract y g_5 g_4 g_3 g_2 g0 g1 g2, cohort(first_treat) ///
	control_cohort(never_treat) absorb(i.id i.year) ///
	covariates(d4f01x d4f02x d4f04x d4f05x d4f06x ///
	d5f01x d5f02x d5f03x d5f05x d5f06 ///
	d6f01x d6f02x d6f03x d6f04x d6f06 ///
	f01x f02x f03x f04x f05x f06x) vce(cluster id)
	
/*
	
* For the treatment periods, these also can be reproduced by the built-in Stata 
* xthdidregress ra. The "ra" refers to the CS version of regression adjustment, and so 
* it is a leads and lags. But the default in xthdidregress does not use the year before the
* intervention in estimating the pre-treatment periods, and that does not appear
* to be an option.

xthdidregress ra (y x) (w), group(id)

* Using the NYT group is not the same:
* xthdidregress ra (y x) (w), group(id) controlg(notyet)

* Can reproduce the pooled regression using 2 x 2 RA methods. The relevant
* cohort is the treated and dinf = 1 is the control. There reference period is 
* g - 1 for treated cohort g. 

reg y c.d4f01 x c.d4f01#c.x_dm4 d4 c.d4#c.x f01 c.f01#c.x if (d4 | dinf) & (f03 | f01), vce(cluster id)
reg y c.d4f02 x c.d4f02#c.x_dm4 d4 c.d4#c.x f02 c.f02#c.x if (d4 | dinf) & (f03 | f02), vce(cluster id)
reg y c.d4f04 x c.d4f04#c.x_dm4 d4 c.d4#c.x f04 c.f03#c.x if (d4 | dinf) & (f03 | f04), vce(cluster id)
reg y c.d4f05 x c.d4f05#c.x_dm4 d4 c.d4#c.x f05 c.f05#c.x if (d4 | dinf) & (f03 | f05), vce(cluster id)
reg y c.d4f06 x c.d4f06#c.x_dm4 d4 c.d4#c.x f06 c.f06#c.x if (d4 | dinf) & (f03 | f06), vce(cluster id)

reg y c.d5f01 x c.d5f01#c.x_dm5 d5 c.d5#c.x f01 c.f01#c.x if (d5 | dinf) & (f04 | f01), vce(cluster id)
reg y c.d5f02 x c.d5f02#c.x_dm5 d5 c.d5#c.x f02 c.f02#c.x if (d5 | dinf) & (f04 | f02), vce(cluster id)
reg y c.d5f03 x c.d5f03#c.x_dm5 d5 c.d5#c.x f03 c.f03#c.x if (d5 | dinf) & (f04 | f03), vce(cluster id)
reg y c.d5f05 x c.d5f05#c.x_dm5 d5 c.d5#c.x f05 c.f05#c.x if (d5 | dinf) & (f04 | f05), vce(cluster id)
reg y c.d5f06 x c.d5f06#c.x_dm5 d5 c.d5#c.x f06 c.f06#c.x if (d5 | dinf) & (f04 | f06), vce(cluster id)

reg y c.d6f01 x c.d6f01#c.x_dm6 d6 c.d6#c.x f01 c.f01#c.x if (d6 | dinf) & (f05 | f01), vce(cluster id)
reg y c.d6f02 x c.d6f02#c.x_dm6 d6 c.d6#c.x f02 c.f02#c.x if (d6 | dinf) & (f05 | f02), vce(cluster id)
reg y c.d6f03 x c.d6f03#c.x_dm6 d6 c.d6#c.x f03 c.f03#c.x if (d6 | dinf) & (f05 | f03), vce(cluster id)
reg y c.d6f04 x c.d6f04#c.x_dm6 d6 c.d6#c.x f04 c.f04#c.x if (d6 | dinf) & (f05 | f04), vce(cluster id)
reg y c.d6f06 x c.d6f06#c.x_dm6 d6 c.d6#c.x f06 c.f06#c.x if (d6 | dinf) & (f05 | f06), vce(cluster id)

* Equivalently, create the long differences and use these in a pure
* cross section regression, as in CS (2021):

gen y_4circle = y - F2.y if f01
reg y_4circle d4 x c.d4#c.x_dm4 if (d4 | dinf) & f01, vce(robust)

replace y_4circle = y - F1.y if f02
reg y_4circle d4 x c.d4#c.x_dm4 if (d4 | dinf) & f02, vce(robust)

replace y_4circle = y - L.y if f04
reg y_4circle d4 x c.d4#c.x_dm4 if (d4 | dinf) & f04, vce(robust)

replace y_4circle = y - L2.y if f05
reg y_4circle d4 x c.d4#c.x_dm4 if (d4 | dinf) & f05, vce(robust)

replace y_4circle = y - L3.y if f06
reg y_4circle d4 x c.d4#c.x_dm4 if (d4 | dinf) & f06, vce(robust)

gen y_5circle = y - F3.y if f01
reg y_5circle d5 x c.d5#c.x_dm5 if (d5 | dinf) & f01, vce(robust)

replace y_5circle = y - F2.y if f02
reg y_5circle d5 x c.d5#c.x_dm5 if (d5 | dinf) & f02, vce(robust)

replace y_5circle = y - F.y if f03
reg y_5circle d5 x c.d5#c.x_dm5 if (d5 | dinf) & f03, vce(robust)

replace y_5circle = y - L.y if f05
reg y_5circle d5 x c.d5#c.x_dm5 if (d5 | dinf) & f05, vce(robust)

replace y_5circle = y - L2.y if f06
reg y_5circle d5 x c.d5#c.x_dm5 if (d5 | dinf) & f06, vce(robust)

gen y_6circle = y - F4.y if f01
reg y_6circle d6 x c.d6#c.x_dm6 if (d6 | dinf) & f01, vce(robust)

replace y_6circle = y - F3.y if f02
reg y_6circle d6 x c.d6#c.x_dm6 if (d6 | dinf) & f02, vce(robust)

replace y_6circle = y - F2.y if f03
reg y_6circle d6 x c.d6#c.x_dm6 if (d6 | dinf) & f03, vce(robust)

replace y_6circle = y - F.y if f04
reg y_6circle d6 x c.d6#c.x_dm6 if (d6 | dinf) & f04, vce(robust)

replace y_6circle = y - L.y if f06
reg y_6circle d6 x c.d6#c.x_dm6 if (d6 | dinf) & f06, vce(robust)



/*

* Dropping the interactions of x with pre-treatment dummies changes the 
* estimated TEs (along with the pre-trends estimates). In this case, since
* PT holds in the data generating, the differences are minor. 
* For testing whether CPT holds, it seems more natural to include only
* the indicators, not the interactions. Or, in the regression with the interactions
* with x, all terms depending on pre-treatment indicators should be tested.

* Without the interactions between pre-treatment indicators and x:

reg y d4f01 d4f02 d4f04 d4f05 d4f06 ///
	d5f01 d5f02 d5f03 d5f05 d5f06 ///
	d6f01 d6f02 d6f03 d6f04 d6f06 ///
	c.d4f04#c.x_dm4 c.d4f05#c.x_dm4 c.d4f06#c.x_dm4 ///
	c.d5f05#c.x_dm5 c.d5f06#c.x_dm5 ///
	c.d6f06#c.x_dm6 ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x ///
	i.year i.year#c.x, vce(cluster id)
	
test c.d4#c.f01 c.d4#c.f02 c.d5#c.f01 c.d5#c.f02 c.d5#c.f03 ///
      c.d6#c.f01 c.d6#c.f02 c.d6#c.f03 c.d6#c.f04

xtreg y d4f01 d4f02 d4f04 d4f05 d4f06 ///
	d5f01 d5f02 d5f03 d5f05 d5f06 ///
	d6f01 d6f02 d6f03 d6f04 d6f06 ///
	c.d4f04#c.x_dm4 c.d4f05#c.x_dm4 c.d4f06#c.x_dm4 ///
	c.d5f05#c.x_dm5 c.d5f06#c.x_dm5 ///
	c.d6f06#c.x_dm6 ///
	i.year i.year#c.x, fe vce(cluster id)
	
*/



