use did_staggered_100000_6, clear

* Generate additional noise; the results will change with every run unless
* the seed is set:
set seed 1234
replace y = y + rnormal(0,30)

xtset id year

list id year y w dinf d14 d15 d16 in 31/60, sep(6)

* Compute cohort shares:

tab dinf if f11
tab d14 if f11
tab d15 if f11
tab d16 if f11

sum x1 if d14
gen x1_dm14 = x1 - r(mean)
sum x1 if d15
gen x1_dm15 = x1 - r(mean)
sum x1 if d16
gen x1_dm16 = x1 - r(mean)

sum x2 if d14
gen x2_dm14 = x2 - r(mean)
sum x2 if d15
gen x2_dm15 = x2 - r(mean)
sum x2 if d16
gen x2_dm16 = x2 - r(mean)

* Compute the SATTs by cohort/year. These are the targets for this
* data set (and, of course, are not available in actual applications).

* Pre- and post-treatment dummies:

gen d14f11 = d14*f11
gen d14f12 = d14*f12
gen d14f13 = d14*f13
gen d14f14 = d14*f14
gen d14f15 = d14*f15
gen d14f16 = d14*f16
gen d15f11 = d15*f11
gen d15f12 = d15*f12
gen d15f13 = d15*f13
gen d15f14 = d15*f14
gen d15f15 = d15*f15
gen d15f16 = d15*f16
gen d16f11 = d16*f11
gen d16f12 = d16*f12
gen d16f13 = d16*f13
gen d16f14 = d16*f14
gen d16f15 = d16*f15
gen d16f16 = d16*f16

* Using the Sun and Abraham (2021) TWFE:

gen first_treat = . if dinf
replace first_treat = 2014 if d14
replace first_treat = 2015 if d15
replace first_treat = 2016 if d16

gen never_treat = first_treat == .

* Generate the relative year variable:

gen ry = 0 if never_treat
replace ry = year - first_treat if first_treat != .

tab ry

forvalues k = 5(-1)1 {
           gen g_`k' = ry == -`k'
        }
forvalues k = 0/2 {
             gen g`k' = ry == `k'
        }

eventstudyinteract y g_5 g_4 g_3 g_2 g0 g1 g2, cohort(first_treat) ///
	control_cohort(never_treat) absorb(i.id i.year) vce(cluster id)

* csdid without controls reproduces the eventstudyinteract:
replace first_treat = 0 if first_treat == .
csdid y, ivar(id) time(year) gvar(first_treat) method(reg) long2
estat event

* Single weighted post-treatment effect:
estat simple



/*
csdid y, ivar(id) time(year) gvar(first_treat) method(reg) long2 notyet
estat event
estat simple
*/

* Following reproduces csdid and obtains standard errors that
* account for sampling errors in the weights. Also, the graph 
* explicitly imposes the normalization of setting the period -1 ATT to
* zero.

gen nw = 1 - w

* Using c.nw, c.w makes the output look better. Using 1.nw, 1.w does, too.
* But both should be avoided for nonlinear models as it means to treat nw, 
* w as continuous variables.

reg y c.nw#c.d14f11 c.nw#c.d14f12 c.w#c.d14f14 c.w#c.d14f15 c.w#c.d14f16 ///
	c.nw#c.d15f11 c.nw#c.d15f12 c.nw#c.d15f13 c.w#c.d15f15 c.w#c.d15f16 ///
	c.nw#c.d16f11 c.nw#c.d16f12 c.nw#c.d16f13 c.nw#c.d16f14 c.w#c.d16f16 ///
	c.d14 c.d15 c.d16 i.year, vce(cluster id)
estimates store reg_did
	
* Generate exposure time dummies:

gen exp0 = d14f14 + d15f15 + d16f16
gen exp1 = d14f15 + d15f16
gen exp2 = d14f16

* Pre-treatment exposure times:

gen expm1 = d14f13 + d15f14 + d16f15
gen expm2 = d14f12 + d15f13 + d16f14
gen expm3 = d14f11 + d15f12 + d16f13
gen expm4 = d15f11 + d16f12
gen expm5 = d16f11

* The following produces the weighted ATTs by exposure time:

margins, dydx(nw) subpop(if expm5 == 1) vce(uncond) post
estimates store att_m5
estimates restore reg_did
margins, dydx(nw) subpop(if expm4 == 1) vce(uncond) post
estimates store att_m4
estimates restore reg_did
margins, dydx(nw) subpop(if expm3 == 1) vce(uncond) post
estimates store att_m3
estimates restore reg_did
margins, dydx(nw) subpop(if expm2 == 1) vce(uncond) post
estimates store att_m2
gen zero = 0
reg zero
estimates store att_m1
estimates restore reg_did
margins, dydx(w) subpop(if exp0 == 1) vce(uncond) post
estimates store att_0
estimates restore reg_did
margins, dydx(w) subpop(if exp1 == 1) vce(uncond) post
estimates store att_1
estimates restore reg_did
margins, dydx(w) subpop(if exp2 == 1) vce(uncond) post
estimates store att_2

* Single weighted effects for pre- and post-treatment.
* The latter reproduces estat simple after csdid:
estimates restore reg_did
margins, dydx(nw) subpop(if nw == 1) vce(uncond)
margins, dydx(w) subpop(if w == 1) vce(uncond)

* lpdid y, unit(id) time(year) treat(w) pre_window(5) post_window(2) nograph
lpdid y, unit(id) time(year) treat(w) pre_window(5) post_window(2) nograph never

* Note: For lpdid, the single, post-intervention average effects is well outside the 
* minimum and maximum of the exposure time effects. It seems that shouldn't
* be possible. The same is sometimes true for the pre-intervention average.

* Using not yet treated units:
csdid y, ivar(id) time(year) gvar(first_treat) method(reg) long2 notyet
estat event
lpdid y, unit(id) time(year) treat(w) pre_window(5) post_window(2) nograph
lpdid y, unit(id) time(year) treat(w) pre_window(5) post_window(2) nograph rw

/*

* Now add the controls.

csdid y x1 x2, ivar(id) time(year) gvar(first_treat) method(reg) long2 
estat event
estat simple

* Again, the flexible regression reproduces csdid. Standard errors are 
* a bit higher because they account for weights and covariate sample average.

qui reg y c.nw#c.d14f11 c.nw#c.d14f12 c.w#c.d14f14 c.w#c.d14f15 c.w#c.d14f16 ///
	c.nw#c.d15f11 c.nw#c.d15f12 c.nw#c.d15f13 c.w#c.d15f15 c.w#c.d15f16 ///
	c.nw#c.d16f11 c.nw#c.d16f12 c.nw#c.d16f13 c.nw#c.d16f14 c.w#c.d16f16 ///
	c.nw#c.d14f11#c.x1_dm14 c.nw#c.d14f12#c.x1_dm14 c.w#c.d14f14#c.x1_dm14 c.w#c.d14f15#c.x1_dm14 c.w#c.d14f16#c.x1_dm14 ///
	c.nw#c.d15f11#c.x1_dm15 c.nw#c.d15f12#c.x1_dm15 c.nw#c.d15f13#c.x1_dm15 c.w#c.d15f15#c.x1_dm15 c.w#c.d15f16#c.x1_dm15 ///
	c.nw#c.d16f11#c.x1_dm16 c.nw#c.d16f12#c.x1_dm16 c.nw#c.d16f13#c.x1_dm16 c.nw#c.d16f14#c.x1_dm16 c.w#c.d16f16#c.x1_dm16 ///
	x1 c.d14#c.x1 c.d15#c.x1 c.d16#c.x1 ///
	c.nw#c.d14f11#c.x2_dm14 c.nw#c.d14f12#c.x2_dm14 c.w#c.d14f14#c.x2_dm14 c.w#c.d14f15#c.x2_dm14 c.w#c.d14f16#c.x2_dm14 ///
	c.nw#c.d15f11#c.x2_dm15 c.nw#c.d15f12#c.x2_dm15 c.nw#c.d15f13#c.x2_dm15 c.w#c.d15f15#c.x2_dm15 c.w#c.d15f16#c.x2_dm15 ///
	c.nw#c.d16f11#c.x2_dm16 c.nw#c.d16f12#c.x2_dm16 c.nw#c.d16f13#c.x2_dm16 c.nw#c.d16f14#c.x2_dm16 c.w#c.d16f16#c.x2_dm16 ///
	x2 c.d14#c.x2 c.d15#c.x2 c.d16#c.x2 ///
	c.d14 c.d15 c.d16 i.year i.year#(c.x1 c.x2), vce(cluster id)
	
estimates store reg_did

margins, dydx(nw) subpop(if expm5 == 1) vce(uncond) post
estimates store att_m5
estimates restore reg_did
margins, dydx(nw) subpop(if expm4 == 1) vce(uncond) post
estimates store att_m4
estimates restore reg_did
margins, dydx(nw) subpop(if expm3 == 1) vce(uncond) post
estimates store att_m3
estimates restore reg_did
margins, dydx(nw) subpop(if expm2 == 1) vce(uncond) post
estimates store att_m2
reg zero
estimates store att_m1
estimates restore reg_did
margins, dydx(w) subpop(if exp0 == 1) vce(uncond) post
estimates store att_0
estimates restore reg_did
margins, dydx(w) subpop(if exp1 == 1) vce(uncond) post
estimates store att_1
estimates restore reg_did
margins, dydx(w) subpop(if exp2 == 1) vce(uncond) post
estimates store att_2

* Single weighted effects for pre- and post-treatment.
* The latter reproduces estat simple after csdid:
estimates restore reg_did
margins, dydx(nw) subpop(if nw == 1) vce(uncond)
margins, dydx(w) subpop(if w == 1) vce(uncond)

lpdid y, unit(id) time(year) treat(w) pre_window(5) post_window(2) controls(x1 x2) nograph
