* Same set of commands can be used with an unbouned corner solution or count outcome.
* use did_staggered_6_corner, clear

use did_staggered_6_count, clear
* log using did_staggered_6_count_20220806, text replace

xtset id year

sum dinf d4 d5 d6 if year == 2001
sum y
count if y == 0

* Exponential model for y, first without covariates, FE Poisson and 
* pooled Poisson given identical parameter estimates, but ATTs come
* from pooled Poisson. Without covariates, get same answer by excluding
* the pre-treatment year dummies.

poisson y c.d4#c.f04 c.d4#c.f05 c.d4#c.f06 ///
	c.d5#c.f05 c.d5#c.f06 ///
	c.d6#c.f06 ///
	f02 f03 f04 f05 f06 d4 d5 d6, vce(cluster id)
	
* Without covariates, the FE Poisson coefficient estimates are the same.
* But it's not clear how one would obtain ATTs (although suggestions
* are out there). Inference would be very difficult.
	
xtpoisson y c.d4#c.f04 c.d4#c.f05 c.d4#c.f06 ///
	c.d5#c.f05 c.d5#c.f06 ///
	c.d6#c.f06 ///
	i.year, fe vce(robust)
	
/*

* Note: This was the original way I devised to compute proper standard errors
* of the heterogeneous ATTs using margins without controls.
	
* Obtain ATTs using margins. Have to include w explicitly. Also, have to 
* set the cohort and year dummies accordingly:

qui poisson y i.w#c.d4#c.f04 i.w#c.d4#c.f05 i.w#c.d4#c.f06 ///
	i.w#c.d5#c.f05 i.w#c.d5#c.f06 ///
	i.w#c.d6#c.f06 ///
	f02 f03 f04 f05 f06 d4 d5 d6, noomitted vce(cluster id)

margins, dydx(w) at(d4 = 1 d5 = 0 d6 = 0 f02 = 0 f03 = 0 f04 = 1 f05 = 0 f06 = 0) ///
	subpop(if d4 == 1) noestimcheck
margins, dydx(w) at(d4 = 1 d5 = 0 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 1 f06 = 0) ///
	subpop(if d4 == 1) noestimcheck   
margins, dydx(w) at(d4 = 1 d5 = 0 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	subpop(if d4 == 1) noestimcheck   
margins, dydx(w) at(d4 = 0 d5 = 1 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 1 f06 = 0) ///
	subpop(if d5 == 1) noestimcheck   
margins, dydx(w) at(d4 = 0 d5 = 1 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	subpop(if d5 == 1) noestimcheck   
margins, dydx(w) at(d4 = 0 d5 = 0 d6 = 1 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	subpop(if d6 == 1) noestimcheck
	
*/
	
* A different and simple way to compute the ATTs and their standard errors.
* It also extends to event study estimation and to the case of exit:

gen d4f04 = d4*f04
gen d4f05 = d4*f05
gen d4f06 = d4*f06
gen d5f05 = d5*f05	
gen d5f06 = d5*f06	
gen d6f06 = d6*f06

poisson y i.d4f04 i.d4f05 i.d4f06 i.d5f05 i.d5f06 i.d6f06 ///
	f02 f03 f04 f05 f06 d4 d5 d6, noomitted vce(cluster id)
	
margins, dydx(d4f04) subpop(if d4f04 == 1) noestimcheck 
margins, dydx(d4f05) subpop(if d4f05 == 1) noestimcheck   
margins, dydx(d4f06) subpop(if d4f06 == 1) noestimcheck  
margins, dydx(d5f05) subpop(if d5f05 == 1) noestimcheck 
margins, dydx(d5f06) subpop(if d5f06 == 1) noestimcheck 
margins, dydx(d6f06) subpop(if d6f06 == 1) noestimcheck 

* Verify imputation estimates are the same [Wooldridge (2021, WP)]:
	
poisson y f02 f03 f04 f05 f06 d4 d5 d6 if ~w
* poisson y i.year d4 d5 d6 if ~w
predict double yinfhat
gen tehat = y - yinfhat
sum tehat if d4f04
sum tehat if d4f05
sum tehat if d4f06
sum tehat if d5f05
sum tehat if d5f06	
sum tehat if d6f06

/*

* Again, this section of code is outdated; left here for posterity and comparison.

* Now with a covariate. Use (time constant) covariates centered about cohort means 
* to get (roughly) proportionate effects as coefficients on the 6 treatment dummies.
* The vce(uncond) option accounts for sampling variation in x:

poisson y i.w#c.d4#c.f04 i.w#c.d4#c.f05 i.w#c.d4#c.f06 ///
	i.w#c.d5#c.f05 i.w#c.d5#c.f06 ///
	i.w#c.d6#c.f06 ///
	i.w#c.d4#c.f04#c.x_dm4 i.w#c.d4#c.f05#c.x_dm4 i.w#c.d4#c.f06#c.x_dm4 ///
	i.w#c.d5#c.f05#c.x_dm5 i.w#c.d5#c.f06#c.x_dm5 ///
	i.w#c.d6#c.f06#c.x_dm6 ///
	f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x, noomitted vce(cluster id)

margins, dydx(w) at(d4 = 1 d5 = 0 d6 = 0 f02 = 0 f03 = 0 f04 = 1 f05 = 0 f06 = 0) ///
	subpop(if d4 == 1) noestimcheck vce(uncond)
margins, dydx(w) at(d4 = 1 d5 = 0 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 1 f06 = 0) ///
	subpop(if d4 == 1) noestimcheck vce(uncond)  
margins, dydx(w) at(d4 = 1 d5 = 0 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	subpop(if d4 == 1) noestimcheck vce(uncond) 
margins, dydx(w) at(d4 = 0 d5 = 1 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 1 f06 = 0) ///
	subpop(if d5 == 1) noestimcheck vce(uncond)
margins, dydx(w) at(d4 = 0 d5 = 1 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	subpop(if d5 == 1) noestimcheck vce(uncond) 
margins, dydx(w) at(d4 = 0 d5 = 0 d6 = 1 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	subpop(if d6 == 1) noestimcheck vce(uncond)
	
* Verify averaging over the cohort subpopulations is sufficient:
	
margins, dydx(w) at(f02 = 0 f03 = 0 f04 = 1 f05 = 0 f06 = 0) ///
	subpop(if d4 == 1) noestimcheck vce(uncond)
margins, dydx(w) at(f02 = 0 f03 = 0 f04 = 0 f05 = 1 f06 = 0) ///
	subpop(if d4 == 1) noestimcheck vce(uncond)  
margins, dydx(w) at(f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	subpop(if d4 == 1) noestimcheck vce(uncond) 
margins, dydx(w) at(f02 = 0 f03 = 0 f04 = 0 f05 = 1 f06 = 0) ///
	subpop(if d5 == 1) noestimcheck vce(uncond)
margins, dydx(w) at(f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	subpop(if d5 == 1) noestimcheck vce(uncond) 
margins, dydx(w) at(f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	subpop(if d6 == 1) noestimcheck vce(uncond)
	
* The following six commands do not produce the proper ATTs:
	
margins, dydx(w) at(d4 = 1 d5 = 0 d6 = 0 f02 = 0 f03 = 0 f04 = 1 f05 = 0 f06 = 0) ///
	noestimcheck vce(uncond)
margins, dydx(w) at(d4 = 1 d5 = 0 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 1 f06 = 0) ///
	noestimcheck vce(uncond)  
margins, dydx(w) at(d4 = 1 d5 = 0 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	noestimcheck vce(uncond) 
margins, dydx(w) at(d4 = 0 d5 = 1 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 1 f06 = 0) ///
	noestimcheck vce(uncond)
margins, dydx(w) at(d4 = 0 d5 = 1 d6 = 0 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	noestimcheck vce(uncond) 
margins, dydx(w) at(d4 = 0 d5 = 0 d6 = 1 f02 = 0 f03 = 0 f04 = 0 f05 = 0 f06 = 1) ///
	noestimcheck vce(uncond)
*/

* The simple way. Also, could use i.year, i.year#c.x instead.

poisson y i.d4f04 i.d4f05 i.d4f06 i.d5f05 i.d5f06 i.d6f06 ///
	i.d4f04#c.x_dm4 i.d4f05#c.x_dm4 i.d4f06#c.x_dm4 ///
	i.d5f05#c.x_dm5 i.d5f06#c.x_dm5 ///
	i.d6f06#c.x_dm6 ///
	f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x, noomitted vce(cluster id)

margins, dydx(d4f04) subpop(if d4f04 == 1) noestimcheck vce(uncond)
margins, dydx(d4f05) subpop(if d4f05 == 1) noestimcheck vce(uncond)  
margins, dydx(d4f06) subpop(if d4f06 == 1) noestimcheck vce(uncond) 
margins, dydx(d5f05) subpop(if d5f05 == 1) noestimcheck vce(uncond)
margins, dydx(d5f06) subpop(if d5f06 == 1) noestimcheck vce(uncond) 
margins, dydx(d6f06) subpop(if d6f06 == 1) noestimcheck vce(uncond)

* Imputation estimates are still the same. 
* Again, no easy way to obtain analytical standard errors.
	
drop yinfhat tehat
	
poisson y f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x /// 
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x if ~w
	
predict double yinfhat
gen tehat = y - yinfhat
sum tehat if d4f04
sum tehat if d4f05
sum tehat if d4f06
sum tehat if d5f05
sum tehat if d5f06	
sum tehat if d6f06

* Event study estimation also is made easier by defining the pre-treatment dummies.
* The omitted time period is the one just before the intervention for all cohorts:

gen d4f01 = d4*f01
gen d4f02 = d4*f02
gen d5f01 = d5*f01	
gen d5f02 = d5*f02
gen d5f03 = d5*f03	
gen d6f01 = d6*f01	
gen d6f02 = d6*f02	
gen d6f03 = d6*f03
gen d6f04 = d6*f04

* To aggregate by exposure time, introduce the time-varying treatment dummy,
* w, and the non-treatment dummy, nw. And, create exposure time dummies.
* Here, "m" stands for "minus."

gen nw = 1 - w
gen exp0 = d4f04 + d5f05 + d6f06
gen exp1 = d4f05 + d5f06
gen exp2 = d4f06
gen expm2 = d4f02 + d5f03 + d6f04
gen expm3 = d4f01 + d5f02 + d6f03
gen expm4 = d5f01 + d6f02
gen expm5 = d6f01

* Full exponential event study estimation. A saturated estimation 
* with the period just before treatment serving as the reference period:

poisson y i.nw#c.d4f01 i.nw#c.d4f02 i.w#c.d4f04 i.w#c.d4f05 i.w#c.d4f06 ///
	i.nw#c.d5f01 i.nw#c.d5f02 i.nw#c.d5f03 i.w#c.d5f05 i.w#c.d5f06 ///
	i.nw#c.d6f01 i.nw#c.d6f02 i.nw#c.d6f03 i.nw#c.d6f04 i.w#c.d6f06 ///
	i.nw#c.d4f01#c.x_dm4 i.nw#c.d4f02#c.x_dm4 i.w#c.d4f04#c.x_dm4 i.w#c.d4f05#c.x_dm4 i.w#c.d4f06#c.x_dm4 ///
	i.nw#c.d5f01#c.x_dm5 i.nw#c.d5f02#c.x_dm5 i.nw#c.d5f03#c.x_dm5 i.w#c.d5f05#c.x_dm5 i.w#c.d5f06#c.x_dm5 ///
	i.nw#c.d6f01#c.x_dm6 i.nw#c.d6f02#c.x_dm6 i.nw#c.d6f03#c.x_dm6 i.nw#c.d6f04#c.x_dm6 i.w#c.d6f06#c.x_dm6 ///
	f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x, noomitted vce(cluster id)
	
estimates store poisson_did
	
margins, dydx(nw) subpop(if expm5 == 1) vce(uncond) noestimcheck post
estimates store att_m5
estimates restore poisson_did
margins, dydx(nw) subpop(if expm4 == 1) vce(uncond) noestimcheck post
estimates store att_m4
estimates restore poisson_did
margins, dydx(nw) subpop(if expm3 == 1) vce(uncond) noestimcheck post
estimates store att_m3
estimates restore poisson_did
margins, dydx(nw) subpop(if expm2 == 1) vce(uncond) noestimcheck post
estimates store att_m2
gen zero = 0
reg zero
estimates store att_m1
estimates restore poisson_did
margins, dydx(w) subpop(if exp0 == 1) vce(uncond) noestimcheck post
estimates store att_0
estimates restore poisson_did
margins, dydx(w) subpop(if exp1 == 1) vce(uncond) noestimcheck post
estimates store att_1
estimates restore poisson_did
margins, dydx(w) subpop(if exp2 == 1) vce(uncond) noestimcheck post
estimates store att_2

coefplot (att_m5, rename(1.nw="-5") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m4, rename(1.nw="-4") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m3, rename(1.nw="-3") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m2, rename(1.nw="-2") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m1, rename(_cons ="-1") mcolor(black)) ///
			(att_0, rename(1.w="0") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_1, rename(1.w="1") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_2, rename(1.w="2") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) , yline(0) vertical ///
			title("Weighted Effects by Exposure Length") ///
			xtitle("Exposure Length") ytitle("Weighted Treatment Effects") nokey
		
graph save did_staggered_6_poisson_es, replace

* Imputation estimation of the ES ATT estimates by exposure time:

poisson y c.d4f01 c.d4f02  ///
	c.d5f01 c.d5f02 c.d5f03 ///
	c.d6f01 c.d6f02 c.d6f03 c.d6f04 ///
	c.d4f01#c.x_dm4 c.d4f02#c.x_dm4 ///
	c.d5f01#c.x_dm5 c.d5f02#c.x_dm5 c.d5f03#c.x_dm5 ///
	c.d6f01#c.x_dm6 c.d6f02#c.x_dm6 c.d6f03#c.x_dm6 c.d6f04#c.x_dm6 ///
	i.year i.year#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x if ~w, noomitted vce(cluster id)
	
drop yinfhat tehat
predict yinfhat
gen tehat = y - yinfhat

sum tehat if exp0
sum tehat if exp1
sum tehat if exp2

/*

* By the Poisson QMLE FOC, the pre-treatment effects are all zero:
sum tehat if expm5
sum tehat if expm4
sum tehat if expm3
sum tehat if expm2

*/

* Linear:

* Linear Model extended TWFE ("lags only"):

reg y c.d4f04 c.d4f05 c.d4f06 c.d5f05 c.d5f06 c.d6f06 ///
	c.d4f04#c.x_dm4 c.d4f05#c.x_dm4 c.d4f06#c.x_dm4 ///
	c.d5f05#c.x_dm5 c.d5f06#c.x_dm5 ///
	c.d6f06#c.x_dm6 ///
	c.year c.year#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x, noomitted vce(cluster id)

* These give SEs adjusted for the sample averages x4bar, x5bar, x6ba6:

margins, dydx(d4f04) subpop(if d4f04 == 1) noestimcheck vce(uncond)
margins, dydx(d4f05) subpop(if d4f05 == 1) noestimcheck vce(uncond)  
margins, dydx(d4f06) subpop(if d4f06 == 1) noestimcheck vce(uncond) 
margins, dydx(d5f05) subpop(if d5f05 == 1) noestimcheck vce(uncond)
margins, dydx(d5f06) subpop(if d5f06 == 1) noestimcheck vce(uncond) 
margins, dydx(d6f06) subpop(if d6f06 == 1) noestimcheck vce(uncond)

* Full event study, linear version:
			
reg y c.nw#c.d4f01 c.nw#c.d4f02 c.w#c.d4f04 c.w#c.d4f05 c.w#c.d4f06 ///
	c.nw#c.d5f01 c.nw#c.d5f02 c.nw#c.d5f03 c.w#c.d5f05 c.w#c.d5f06 ///
	c.nw#c.d6f01 c.nw#c.d6f02 c.nw#c.d6f03 c.nw#c.d6f04 c.w#c.d6f06 ///
	c.nw#c.d4f01#c.x_dm4 c.nw#c.d4f02#c.x_dm4 c.w#c.d4f04#c.x_dm4 c.w#c.d4f05#c.x_dm4 c.w#c.d4f06#c.x_dm4 ///
	c.nw#c.d5f01#c.x_dm5 c.nw#c.d5f02#c.x_dm5 c.nw#c.d5f03#c.x_dm5 c.w#c.d5f05#c.x_dm5 c.w#c.d5f06#c.x_dm5 ///
	c.nw#c.d6f01#c.x_dm6 c.nw#c.d6f02#c.x_dm6 c.nw#c.d6f03#c.x_dm6 c.nw#c.d6f04#c.x_dm6 c.w#c.d6f06#c.x_dm6 ///
	f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x, noomitted vce(cluster id)
	
test c.nw#c.d4f01 c.nw#c.d4f02 c.nw#c.d5f01 c.nw#c.d5f02 c.nw#c.d5f03 ///
	c.nw#c.d6f01 c.nw#c.d6f02 c.nw#c.d6f03 c.nw#c.d6f04
	
* The joint ES test does not reject with p-value > 0.15.
* However, two of the pre-intervention exposure time estimates
* are statistically different from zero at 5%.
	
estimates store reg_did
	
margins, dydx(nw) subpop(if expm5 == 1) vce(uncond) post
estimates store att_m5
estimates restore reg_did
margins, dydx(nw) subpop(if expm4 == 1) vce(uncond) post
estimates store att_m4
estimates restore reg_did
margins, dydx(nw) subpop(if expm3 == 1) vce(uncond) post
estimates store att_m3
estimates restore reg_did
margins, dydx(nw) subpop(if expm2 == 1) vce(uncond) post
estimates store att_m2
reg zero
estimates store att_m1
estimates restore reg_did
margins, dydx(w) subpop(if exp0 == 1) vce(uncond) post
estimates store att_0
estimates restore reg_did
margins, dydx(w) subpop(if exp1 == 1) vce(uncond) post
estimates store att_1
estimates restore reg_did
margins, dydx(w) subpop(if exp2 == 1) vce(uncond) post
estimates store att_2

coefplot (att_m5, rename(nw="-5") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m4, rename(nw="-4") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m3, rename(nw="-3") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m2, rename(nw="-2") mcolor(black) ciopts(lcolor(blue) recast(rcap) lwidth(0.5))) ///
			(att_m1, rename(_cons ="-1") mcolor(black)) ///
			(att_0, rename(w="0") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_1, rename(w="1") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) ///
			(att_2, rename(w="2") mcolor(black) ciopts(lcolor(red) recast(rcap) lwidth(0.5))) , yline(0) vertical ///
			title("Weighted Effects by Exposure Length") ///
			xtitle("Exposure Length") ytitle("Weighted Treatment Effects") nokey
			
graph save did_staggered_6_linear_es, replace

* CS with linear regression, but using doubly robust estimator. The
* conditional PT assumption is rejected because the assumption holds in the
* log of the expected value, not the expected value. The DR nature of CS
* doesn't help here.

gen first_treat = 0
replace first_treat = 2004 if d4
replace first_treat = 2005 if d5
replace first_treat = 2006 if d6
csdid y x, ivar(id) time(year) gvar(first_treat) method(reg) long2
estat event
csdid_plot

			
* With heterogeneous trends:

gen t = year - 2000
	
poisson y i.d4f04 i.d4f05 i.d4f06 i.d5f05 i.d5f06 i.d6f06 ///
	i.d4f04#c.x_dm4 i.d4f05#c.x_dm4 i.d4f06#c.x_dm4 ///
	i.d5f05#c.x_dm5 i.d5f06#c.x_dm5 ///
	i.d6f06#c.x_dm6 ///
	f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x ///
	c.d4#c.t c.d5#c.t c.d6#c.t, noomitted vce(cluster id)
test c.d4#c.t c.d5#c.t c.d6#c.t

margins, dydx(d4f04) subpop(if d4f04 == 1) noestimcheck vce(uncond)
margins, dydx(d4f05) subpop(if d4f05 == 1) noestimcheck vce(uncond)  
margins, dydx(d4f06) subpop(if d4f06 == 1) noestimcheck vce(uncond) 
margins, dydx(d5f05) subpop(if d5f05 == 1) noestimcheck vce(uncond)
margins, dydx(d5f06) subpop(if d5f06 == 1) noestimcheck vce(uncond) 
margins, dydx(d6f06) subpop(if d6f06 == 1) noestimcheck vce(uncond)

/*
* Same using year in place of t, but the coefficients on d4, d5, d6 not easy to interpret. 

poisson y i.d4f04 i.d4f05 i.d4f06 i.d5f05 i.d5f06 i.d6f06 ///
	i.d4f04#c.x_dm4 i.d4f05#c.x_dm4 i.d4f06#c.x_dm4 ///
	i.d5f05#c.x_dm5 i.d5f06#c.x_dm5 ///
	i.d6f06#c.x_dm6 ///
	f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x ///
	c.d4#c.year c.d5#c.year c.d6#c.year, noomitted vce(cluster id)
	
test c.d4#c.year c.d5#c.year c.d6#c.year

margins, dydx(d4f04) subpop(if d4f04 == 1) noestimcheck vce(uncond)
margins, dydx(d4f05) subpop(if d4f05 == 1) noestimcheck vce(uncond)  
margins, dydx(d4f06) subpop(if d4f06 == 1) noestimcheck vce(uncond) 
margins, dydx(d5f05) subpop(if d5f05 == 1) noestimcheck vce(uncond)
margins, dydx(d5f06) subpop(if d5f06 == 1) noestimcheck vce(uncond) 
margins, dydx(d6f06) subpop(if d6f06 == 1) noestimcheck vce(uncond)

*/
	
* Imputation with heterogeneous trends:

drop yinfhat tehat

poisson y f02 f03 f04 f05 f06 ///
	c.f02#c.x c.f03#c.x c.f04#c.x c.f05#c.x c.f06#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x ///
	c.d4#c.t c.d5#c.t c.d6#c.t if ~w, noomitted vce(cluster id)
test c.d4#c.t c.d5#c.t c.d6#c.t 

predict double yinfhat
gen tehat = y - yinfhat
sum tehat if d4f04
sum tehat if d4f05
sum tehat if d4f06
sum tehat if d5f05
sum tehat if d5f06	
sum tehat if d6f06

* Test for non-parallel trends in linear model using three heterogeneous linear 
* trends. In this case, it does not reject at anything close to the 5% level. 
* The ES test does effectively find violation of conditional PT.

reg y c.d4f04 c.d4f05 c.d4f06 c.d5f05 c.d5f06 c.d6f06 ///
	c.d4f04#c.x_dm4 c.d4f05#c.x_dm4 c.d4f06#c.x_dm4 ///
	c.d5f05#c.x_dm5 c.d5f06#c.x_dm5 ///
	c.d6f06#c.x_dm6 ///
	c.year c.year#c.x ///
	d4 d5 d6 x c.d4#c.x c.d5#c.x c.d6#c.x ///
	c.d4#c.t c.d5#c.t c.d6#c.t, noomitted vce(cluster id)
	
test c.d4#c.t c.d5#c.t c.d6#c.t
	


	



